@@ -26,12 +26,12 @@ import os, sys, shutil, glob, errno
 from itertools import chain
 
 # TODO: Import only the official interface
-from output import *
-from paths import *
-from signatures import *
-from cache import *
-from codegeneration import *
-from locking import file_lock
+from .output import *
+from .paths import *
+from .signatures import *
+from .cache import *
+from .codegeneration import *
+from .locking import file_lock
 
 def assert_is_str(x):
     instant_assert(isinstance(x, str),
@@ -62,7 +62,7 @@ def makedirs(path):
     """
     try:
         os.makedirs(path)
-    except os.error, e:
+    except os.error as e:
         if e.errno != errno.EEXIST:
             raise
 
@@ -167,7 +167,7 @@ def recompile(modulename, module_path, new_compilation_checksum,
     finally:
         compile_log_file.close()
         if ret != 0:
-            if "INSTANT_DISPLAY_COMPILE_LOG" in os.environ.keys():
+            if "INSTANT_DISPLAY_COMPILE_LOG" in list(os.environ.keys()):
                 instant_warning("")
                 instant_warning("Content of instant compile.log")
                 instant_warning("==============================")
@@ -198,12 +198,12 @@ def copy_to_cache(module_path, cache_dir, modulename, \
             instant_warning("In instant.build_module: Path '%s' already exists,"\
                 " but module wasn't found in cache previously. Not overwriting,"\
                 " assuming this module is valid." % cache_module_path)
-        
+
             return cache_module_path
-        
+
             # Not deleting anymore, relying on locking system
             #shutil.rmtree(cache_module_path, ignore_errors=True)
-        
+
         # Error checks
         instant_assert(os.path.isdir(module_path), "In instant.build_module:"\
                        " Cannot copy non-existing directory %r!" % module_path)
@@ -212,13 +212,13 @@ def copy_to_cache(module_path, cache_dir, modulename, \
                           " exist at this point!" % cache_module_path)
         instant_debug("In instant.build_module: Copying built module from %r"\
             " to cache at %r" % (module_path, cache_module_path))
-        
+
         # Do the copying and mark that we are finished by creating an empty file
         # finished_copying
         try:
             shutil.copytree(module_path, cache_module_path)
-            open(os.path.join(cache_module_path, "finished_copying"), "w")
-        except OSError, e:
+            open(os.path.join(cache_module_path, "finished_copying"), "w").close()
+        except OSError as e:
             if e.errno != errno.EEXIST:
                 raise
         finally:
@@ -346,6 +346,9 @@ def build_module(modulename=None, source_directory=".",
 
     # --- Validate arguments
 
+    if sys.version_info[0] > 2:
+        swigargs = swigargs + ['-py3']
+
     instant_assert(modulename is None or isinstance(modulename, str),
         "In instant.build_module: Expecting modulename to be string or None.")
     assert_is_str(source_directory)
@@ -497,7 +500,8 @@ def build_module(modulename=None, source_directory=".",
         os.chdir(module_path)
 
         # Generate __init__.py which imports compiled module contents
-        write_file("__init__.py", "from %s import *" % modulename)
+        write_file("__init__.py", "from __future__ import absolute_import\nfrom .%s import *" \
+                    % modulename)
 
         # Generate SWIG interface if wanted
         ifile_name = "%s.i" % modulename
@@ -566,7 +570,7 @@ def build_module(modulename=None, source_directory=".",
 
         # Import module and place in memory cache
         module = import_and_cache_module(module_path, modulename, moduleids)
-            
+
         if not module:
             instant_error("Failed to import newly compiled module!")
 
