@@ -22,9 +22,10 @@
 #
 # Alternatively, Instant may be distributed under the terms of the BSD license.
 
+import sys
 import re, os
-from output import instant_assert, instant_warning, instant_debug, write_file
-from config import get_swig_binary
+from .output import instant_assert, instant_warning, instant_debug, write_file
+from .config import get_swig_binary
 
 def mapstrings(format, sequence):
     return "\n".join(format % i for i in sequence)
@@ -59,7 +60,6 @@ def reindent(code):
     instant_assert(space == " "*n, "Logic breach in reindent.")
     return "\n".join(re.sub(r"^%s" % space, "", l) for l in lines)
 
-
 def write_interfacefile(filename, modulename, code, init_code,
                         additional_definitions, additional_declarations,
                         system_headers, local_headers, wrap_headers, arrays):
@@ -89,7 +89,7 @@ def write_interfacefile(filename, modulename, code, init_code,
                    'unsigned short', 'unsigned int', 'unsigned long',
                    'unsigned long long']
     for a in arrays:
-        if type(a) == tuple:
+        if isinstance(a, tuple):
             a = list(a)
         DATA_TYPE = 'double'
         for vt in valid_types:
@@ -241,12 +241,14 @@ def write_setup(filename, modulename, csrcs, cppsrcs, local_headers, include_dir
     if len(local_headers) > 0:
         swig_include_dirs += " -I.."
 
+    py3 = "" if sys.version_info[0] < 3 else "-py3"
+
     # Generate code
     code = reindent("""
         import os
         from distutils.core import setup, Extension
         name = '%s'
-        swig_cmd =r'%s -python %s %s %s'
+        swig_cmd =r'%s -python %s %s %s %s'
         os.system(swig_cmd)
         sources = %s
         setup(name = '%s',
@@ -255,7 +257,7 @@ def write_setup(filename, modulename, csrcs, cppsrcs, local_headers, include_dir
                              include_dirs=%s,
                              library_dirs=%s,
                              libraries=%s %s %s)])
-        """ % (modulename, get_swig_binary(), swig_include_dirs, swig_args, \
+        """ % (modulename, get_swig_binary(), py3, swig_include_dirs, swig_args, \
                swigfilename, cppsrcs, modulename, modulename, include_dirs, \
                library_dirs, libraries, compile_args, link_args))
 
@@ -277,7 +279,7 @@ def _test_write_interfacefile():
     write_interfacefile("%s.i" % modulename, modulename, code, init_code, \
                         additional_definitions, additional_declarations, \
                         system_headers, local_headers, wrap_headers, arrays)
-    print "".join(open("%s.i" % modulename).readlines())
+    print("".join(open("%s.i" % modulename).readlines()))
 
 def _test_write_setup():
     modulename = "testmodule"
@@ -295,12 +297,10 @@ def _test_write_setup():
     write_setup("setup.py", modulename, csrcs, cppsrcs, local_headers, \
                 include_dirs, library_dirs, libraries, swig_include_dirs, \
                 swigargs, cppargs, lddargs)
-    print "".join(open("setup.py").readlines())
+    print("".join(open("setup.py").readlines()))
 
-def unique(list):
-    set = {}
-    map(set.__setitem__, list, [])
-    return set.keys()
+def unique(sequence):
+    return list(set(sequence))
 
 
 def find_vtk_classes(str):
@@ -384,6 +384,12 @@ ENDIF(%(package)s_FOUND)
 
     cmake_form["extra_swigargs"] = " ".join(swigargs)
 
+    cmake_form["swig_executable"] =  "\n".join(\
+        """if (DEFINED %(package)s_SWIG_EXECUTABLE)
+  set(SWIG_EXECUTABLE ${%(package)s_SWIG_EXECUTABLE})
+endif()
+""" % dict(package=package.upper()) for package in cmake_packages)
+
 
     cmake_form["find_packages"] = "\n\n".join(find_package_template % \
                                               dict(package=package,
@@ -449,6 +455,8 @@ PROJECT(${NAME})
 %(cppargs)s
 %(lddargs)s
 
+%(swig_executable)s
+
 find_package(SWIG REQUIRED)
 include(${SWIG_USE_FILE})
 
@@ -490,6 +498,13 @@ endif()
 
 %(package_python_definitions)s
 
+# Work-around for bug in CMake 3.0.0 (see
+# http://www.cmake.org/Bug/view.php?id=14990)
+set(SWIG_MODULE_NAME_ORIG "${SWIG_MODULE_NAME}")
+if (${CMAKE_VERSION} MATCHES "3.0.0")
+  set(SWIG_MODULE_NAME "_${SWIG_MODULE_NAME}")
+endif()
+
 swig_add_module(${SWIG_MODULE_NAME} python ${SWIG_SOURCES})
 
 set(EXTRA_LIBRARIES %(extra_libraries)s)
@@ -563,6 +578,13 @@ include_directories(${PYTHON_INCLUDE_PATH} ${%(name)s_SOURCE_DIR})
 
 set(VTK_LIBS ITKCommon vtkCommon vtkImaging vtkIO vtkFiltering vtkRendering vtkGraphics vtkCommonPythonD vtkFilteringPythonD)
 
+# Work-around for bug in CMake 3.0.0 (see
+# http://www.cmake.org/Bug/view.php?id=14990)
+set(SWIG_MODULE_NAME_ORIG "${SWIG_MODULE_NAME}")
+if (${CMAKE_VERSION} MATCHES "3.0.0")
+  set(SWIG_MODULE_NAME "_${SWIG_MODULE_NAME}")
+endif()
+
 swig_add_module(${SWIG_MODULE_NAME} python ${SWIG_SOURCES})
 
 swig_link_libraries(${SWIG_MODULE_NAME} ${PYTHON_LIBRARIES} ${VTK_LIBS})
@@ -600,12 +622,9 @@ ENDIF(VTK_FOUND)
 #  INCLUDE(${VMTK_USE_FILE})
 #ENDIF(ITK_FOUND)
 
-
-
 find_package(SWIG REQUIRED)
 include(${SWIG_USE_FILE})
 
-
 set(SWIG_MODULE_NAME %(name)s)
 set(CMAKE_SWIG_FLAGS
   -module ${SWIG_MODULE_NAME}
@@ -636,6 +655,13 @@ link_directories(/usr/local/lib/vmtk .)
 set(VTK_LIBS ITKCommon vtkCommon vtkImaging vtkIO vtkFiltering vtkRendering vtkGraphics vtkCommonPythonD vtkFilteringPythonD)
 set(VMTK_LIBS vtkvmtkCommonPythonD vtkvmtkITKPythonD vtkvmtkCommon vtkvmtkITK vtkvmtkComputationalGeometryPythonD vtkvmtkMiscPythonD vtkvmtkComputationalGeometry vtkvmtkMisc vtkvmtkDifferentialGeometryPythonD vtkvmtkSegmentationPythonD vtkvmtkDifferentialGeometry vtkvmtkSegmentation vtkvmtkIOPythonD)
 
+# Work-around for bug in CMake 3.0.0 (see
+# http://www.cmake.org/Bug/view.php?id=14990)
+set(SWIG_MODULE_NAME_ORIG "${SWIG_MODULE_NAME}")
+if (${CMAKE_VERSION} MATCHES "3.0.0")
+  set(SWIG_MODULE_NAME "_${SWIG_MODULE_NAME}")
+endif()
+
 swig_add_module(${SWIG_MODULE_NAME} python ${SWIG_SOURCES})
 
 swig_link_libraries(${SWIG_MODULE_NAME} ${PYTHON_LIBRARIES} ${VTK_LIBS} ${VMTK_LIBS})
@@ -657,5 +683,5 @@ def write_vtk_interface_file(signature, code):
 
 if __name__ == "__main__":
     _test_write_interfacefile()
-    print "\n"*3
+    print("\n"*3)
     _test_write_setup()
