@@ -1,8 +1,9 @@
+from __future__ import print_function
 
 try:
     from dolfin import *
 except:
-    print "dolfin not installed..."
+    print("dolfin not installed...")
     exit()
 
 import instant
